==> ktorrent-5.0.1.tar.xz: ktorrent-5.0.1/plugins/infowidget/availabilitychunkbar.h <==
/***************************************************************************
 *   Copyright (C) 2005-2007 by Joris Guisson                              *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/
#ifndef AVAILABILITYCHUNKBAR_H
#define AVAILABILITYCHUNKBAR_H

#include <torrent/chunkbar.h>
#include <interfaces/torrentinterface.h>

namespace kt
{

    /**
    @author Joris Guisson
    */
    class AvailabilityChunkBar : public ChunkBar
    {
        Q_OBJECT
    public:
        AvailabilityChunkBar(QWidget* parent);
        virtual ~AvailabilityChunkBar();

        virtual const bt::BitSet& getBitSet() const;

        void setTC(bt::TorrentInterface* tc);
    private:
        bt::TorrentInterface* curr_tc;
    };
}

#endif

==> ktorrent-5.1.1.tar.xz: ktorrent-5.1.1/plugins/infowidget/availabilitychunkbar.h <==
/***************************************************************************
 *   Copyright (C) 2005-2007 by Joris Guisson                              *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef AVAILABILITYCHUNKBAR_H
#define AVAILABILITYCHUNKBAR_H

#include <torrent/chunkbar.h>
#include <interfaces/torrentinterface.h>

namespace kt
{

    /**
    @author Joris Guisson
    */
    class AvailabilityChunkBar : public ChunkBar
    {
        Q_OBJECT
    public:
        AvailabilityChunkBar(QWidget* parent);
        ~AvailabilityChunkBar();

        const bt::BitSet& getBitSet() const override;

        void setTC(bt::TorrentInterface* tc);
    private:
        bt::TorrentInterface* curr_tc;
    };
}

#endif
